//
// Cell Phone Speaker Sound Chamber
//  - licensed under the Creative Commons - Attribution license.
//  version 2
//
// Deal57 - 2017-07
//
// Simple sound chamber for cell phone speaker
//  e.g. Part number: CUI CDS-16098A
//
// Ideal sealed sound chamber is at least 1cm3, so 
//  this chamber is over 1000mm3, target between 1200-1400mm3
//
// spk_l, spk_w, and spk_z are the dimensions -- ex. 15 x 11 x 3.5
// 
// The box has a wall of m * 2 with a cut out for the speaker on the top.

$fn=32;

spk_l = 16;
spk_w = 9;
spk_d = 3.0 - 1.5;  // depth of speaker - leave 1.5 mm out of the box

fit = .1; // add to inner dimensions to allow for fit

m = 1.0; // thickness of wall
m2 = m + m;

rot_x = 0; // angle of rotation for display, if needed

box_h = 0; // height of the box from 0, minkowski adds (m) under the box height
box_x = spk_l + fit; // length of the box
box_y = spk_w + fit; // width of the box
box_z = round((1200 / (box_x * box_y)) + .5); // up to about 10mm;
    // depth of the inside of the box - we want about 1000-1200mm3 airspace
box_xyz = box_x * box_y * box_z;

echo(box_x = box_x, box_y=box_y, box_z=box_z);
echo(cm3 = box_xyz / 1000);
translate([0,0,0])
spk_box();

module spk_box() {
    difference() {
        union() {       
            difference() {
                rotate ([rot_x,0,0])
                translate ([0, 0, box_h])
                minkowski() {
                    cube([box_x, box_y, box_z]);
                    sphere(m);
                }
                // cut wall around speaker
                rotate ([rot_x,0,0])
                translate ([0, 0, box_h + (box_z - spk_d)])
                    cube([box_x, box_y, spk_d]);

                // cut inner part
                rotate ([rot_x,0,0])
                translate ([m, m, box_h])
                    cube([box_x - m2, box_y -m2 , box_z - spk_d]);

                // cut top of tray 
                rotate ([rot_x,0,0])
                translate([-m, -m, box_h + box_z])
                    cube([box_x + m2, box_y + m2 , m2]);
            }
        }
     }
}